@@ -26,6 +26,13 @@ superType <- function(object) {
 }
 
 
+#' @keywords internal
+superType.default <- function(object) {
+  warning('`type` could not be determined; assuming `type = "regression"`')
+  "regression"
+}
+
+
 #' @keywords internal
 superType.bagging <- function(object) {
   "classification"
@@ -38,12 +45,24 @@ superType.boosting <- function(object) {
 }
 
 
+#' @keywords internal
+superType.cubist <- function(object) {
+  "regression"
+}
+
+
+#' @keywords internal
+superType.C5.0 <- function(object) {
+  "classification"
+}
+
+
 #' @keywords internal
 superType.earth <- function(object) {
-  if (!is.null(object$glm.list) && 
+  if (!is.null(object$glm.list) &&
       object$glm.list[[1L]]$family$family == "binomial") {
     "classification"
-  } else if (is.null(object$glm.list) || 
+  } else if (is.null(object$glm.list) ||
              object$glm.list[[1L]]$family$family == "gaussian") {
     "regression"
   } else {
@@ -59,6 +78,12 @@ superType.lm <- function(object) {
 }
 
 
+#' @keywords internal
+superType.nls <- function(object) {
+  "regression"
+}
+
+
 #' @keywords internal
 superType.glm <- function(object) {
   if(object$family$family == "binomial") {
@@ -141,14 +166,14 @@ superType.gbm <- function(object) {
 superType.xgb.Booster <- function(object) {
   if (object$params$objective == "reg:linear") {
     "regression"
-  } else if (object$params$objective %in% 
+  } else if (object$params$objective %in%
              c("binary:logistic", "multi:softprob")) {
-    # FIXME: Throw a warning if objective function is classification, but does 
+    # FIXME: Throw a warning if objective function is classification, but does
     # not return the predicted probabilities (e.g., "binary:logitraw").
     "classification"
-  } else if (object$params$objective %in% 
+  } else if (object$params$objective %in%
              c("reg:logistic", "binary:logitraw", "multi:softmax")) {
-    stop(paste0("For classification, switch to an objective function", 
+    stop(paste0("For classification, switch to an objective function",
                 "that returns the predicted probabilities."))
   } else {
     "other"
@@ -162,7 +187,7 @@ superType.svm <- function(object) {
     "regression"
   } else {
     "classification"
-  } 
+  }
 }
 
 
